@@ -105,7 +105,7 @@ void Mixer::event()
         m_sampleIndex++; // FIXME this might break HardSID
 
     /* Post a callback to ourselves. */
-    event_context.schedule(*this, MIXER_EVENT_RATE, EVENT_CLOCK_PHI1);
+    event_context.schedule(*this, MIXER_EVENT_RATE);
 }
 
 void Mixer::begin(short *buffer, uint_least32_t count)
